aboutsummaryrefslogtreecommitdiffstats
path: root/wiretap/eyesdn.c
diff options
context:
space:
mode:
Diffstat (limited to 'wiretap/eyesdn.c')
-rw-r--r--wiretap/eyesdn.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/wiretap/eyesdn.c b/wiretap/eyesdn.c
index 7835625941..ba674d48f7 100644
--- a/wiretap/eyesdn.c
+++ b/wiretap/eyesdn.c
@@ -43,7 +43,8 @@
* Each Frame starts with the 0xff Flag byte
* - Bytes 0-2: timestamp (long usec in network byte order)
* - Bytes 3-7: timestamp (40bits sec since 1970 in network byte order)
* - Byte 8: channel (0 for D channel, 1-30 for B1-B30, 129 for ATM)
* - Byte 9: Sender (0 NT, 1 TE)
* - Byte 10-11: frame size in bytes
* - Byte 12-n: Frame Payload
@@ -227,7 +228,7 @@ parse_eyesdn_rec_hdr(wtap *wth, FILE_T fh,
guint8 hdr[EYESDN_HDR_LENGTH];
unsigned long secs, usecs;
int pkt_len;
- unsigned int channel, direction;
+ guint8 channel, direction;
/* Our file pointer should be at the summary information header
* for a packet. Read in that header and extract the useful
@@ -260,7 +261,7 @@ parse_eyesdn_rec_hdr(wtap *wth, FILE_T fh,
pkt_len = (pkt_len << 8) | ((unsigned long) hdr[11]);
/* sanity checks */
- if((channel>30)&&(channel!=129)) {
+ if((channel>30)&&(channel<128)) {
*err = WTAP_ERR_BAD_RECORD;
*err_info = g_strdup_printf("eyesdn: bad channel number %u",
channel);
@@ -43,7 +43,8 @@
* - Bytes 0-2: timestamp (long usec in network byte order)
* - Bytes 3-7: timestamp (40bits sec since 1970 in network byte order)
- * - Byte 8: channel (0 for D channel, 1-30 for B1-B30, 129 for ATM)
+ * - Byte 8: channel (0 for D channel, 1-30 for B1-B30,
+ * 128 ATM cells, 129 ATM layer indications)
* - Byte 9: Sender (0 NT, 1 TE)
* - Byte 10-11: frame size in bytes